@@ -21,34 +21,34 @@ build_time_vars = {'ABIFLAGS': 'd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1  '
-           '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-           '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-           '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-           '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv  -O0 -Wno-cpp',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare '
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
+           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
+           '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
+           '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
+           '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-m64 -march=x86-64-v2 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -92,7 +92,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--with-pydebug' "
                 "'build_alias=x86_64-redhat-linux-gnu' "
-                "'host_alias=x86_64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
+                "'host_alias=x86_64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -659,7 +659,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
@@ -698,29 +698,28 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  '
-                             '-fexceptions -g -grecord-gcc-switches -pipe '
-                             '-Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
-                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
-                             '-fstack-protector-strong   -m64 -march=x86-64-v2 '
-                             '-mtune=generic -fasynchronous-unwind-tables '
-                             '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
-                             '-fstack-protector-strong   -m64 -march=x86-64-v2 '
-                             '-mtune=generic -fasynchronous-unwind-tables '
-                             '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions '
                              '-g -grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=x86-64-v2 '
                              '-mtune=generic -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -O2 '
+                             '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
+                             '-fstack-protector-strong   -m64 -march=x86-64-v2 '
+                             '-mtune=generic -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
+                             '-fstack-protector-strong   -m64 -march=x86-64-v2 '
+                             '-mtune=generic -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -738,10 +737,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -756,23 +755,23 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-I/builddir/build/BUILD/Python-3.9.19/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions '
-              '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+              '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions '
-              '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+              '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
               '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -787,7 +786,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -801,27 +800,26 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -m64 -march=x86-64-v2 '
                    '-mtune=generic -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv -O2  -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
-                   '-fstack-protector-strong   -m64 -march=x86-64-v2 '
-                   '-mtune=generic -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv  -O2  -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
-                   '-fstack-protector-strong   -m64 -march=x86-64-v2 '
-                   '-mtune=generic -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv  -O0 -Wno-cpp -O2 -flto=auto '
-                   '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
+                   '-fPIC -fwrapv -fexceptions -g -grecord-gcc-switches -pipe '
+                   '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=x86-64-v2 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    '
+                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=x86-64-v2 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
@@ -834,7 +832,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -877,27 +875,27 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
+                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0 '
-                        '-Wno-cpp -O2 -flto=auto -ffat-lto-objects '
-                        '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                        '-Wno-cpp -flto=auto -ffat-lto-objects -fexceptions -g '
+                        '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -911,7 +909,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
